@@ -9,7 +9,7 @@ use Test::More;
 
 use Yahoo::Marketing::Account;
 
-sub test_can_create_account_and_set_all_fields : Test(16) {
+sub test_can_create_account_and_set_all_fields : Test(21) {
 
     my $account = Yahoo::Marketing::Account->new
                                            ->ID( 'id' )
@@ -17,10 +17,15 @@ sub test_can_create_account_and_set_all_fields : Test(16) {
                                            ->businessTypeCode( 'business type code' )
                                            ->contentMatchON( 'content match on' )
                                            ->displayURL( 'display url' )
+                                           ->fiscalCode( 'fiscal code' )
+                                           ->hasFiscalCode( 'has fiscal code' )
+                                           ->hasNifCif( 'has nif cif' )
+                                           ->hasVatRegistrationNumber( 'has vat registration number' )
                                            ->marketID( 'market id' )
                                            ->masterAccountID( 'master account id' )
                                            ->name( 'name' )
                                            ->nameFurigana( 'name furigana' )
+                                           ->nifCif( 'nif cif' )
                                            ->personalID( 'personal id' )
                                            ->sitePassword( 'site password' )
                                            ->siteUserName( 'site user name' )
@@ -36,10 +41,15 @@ sub test_can_create_account_and_set_all_fields : Test(16) {
     is( $account->businessTypeCode, 'business type code', 'can get business type code' );
     is( $account->contentMatchON, 'content match on', 'can get content match on' );
     is( $account->displayURL, 'display url', 'can get display url' );
+    is( $account->fiscalCode, 'fiscal code', 'can get fiscal code' );
+    is( $account->hasFiscalCode, 'has fiscal code', 'can get has fiscal code' );
+    is( $account->hasNifCif, 'has nif cif', 'can get has nif cif' );
+    is( $account->hasVatRegistrationNumber, 'has vat registration number', 'can get has vat registration number' );
     is( $account->marketID, 'market id', 'can get market id' );
     is( $account->masterAccountID, 'master account id', 'can get master account id' );
     is( $account->name, 'name', 'can get name' );
     is( $account->nameFurigana, 'name furigana', 'can get name furigana' );
+    is( $account->nifCif, 'nif cif', 'can get nif cif' );
     is( $account->personalID, 'personal id', 'can get personal id' );
     is( $account->sitePassword, 'site password', 'can get site password' );
     is( $account->siteUserName, 'site user name', 'can get site user name' );
