@@ -9,12 +9,13 @@ use Test::More;
 
 use Yahoo::Marketing::CampaignOptimizationGuidelinesResponse;
 
-sub test_can_create_campaign_optimization_guidelines_response_and_set_all_fields : Test(4) {
+sub test_can_create_campaign_optimization_guidelines_response_and_set_all_fields : Test(5) {
 
     my $campaign_optimization_guidelines_response = Yahoo::Marketing::CampaignOptimizationGuidelinesResponse->new
                                                                                                             ->campaignOptimizationGuidelines( 'campaign optimization guidelines' )
                                                                                                             ->errors( 'errors' )
                                                                                                             ->operationSucceeded( 'operation succeeded' )
+                                                                                                            ->warnings( 'warnings' )
                    ;
 
     ok( $campaign_optimization_guidelines_response );
@@ -22,6 +23,7 @@ sub test_can_create_campaign_optimization_guidelines_response_and_set_all_fields
     is( $campaign_optimization_guidelines_response->campaignOptimizationGuidelines, 'campaign optimization guidelines', 'can get campaign optimization guidelines' );
     is( $campaign_optimization_guidelines_response->errors, 'errors', 'can get errors' );
     is( $campaign_optimization_guidelines_response->operationSucceeded, 'operation succeeded', 'can get operation succeeded' );
+    is( $campaign_optimization_guidelines_response->warnings, 'warnings', 'can get warnings' );
 
 };
 
